@@ -17,6 +17,9 @@ package service
 import (
 	"errors"
 	"fmt"
+	"io/ioutil"
+	"os"
+	"path/filepath"
 	"reflect"
 	"strings"
 	"testing"
@@ -27,9 +30,9 @@ import (
 	"k8s.io/apimachinery/pkg/watch"
 
 	"knative.dev/client/pkg/kn/commands"
-	servinglib "knative.dev/client/pkg/serving"
 	"knative.dev/client/pkg/util"
 	"knative.dev/client/pkg/wait"
+	network "knative.dev/networking/pkg"
 
 	corev1 "k8s.io/api/core/v1"
 	"k8s.io/apimachinery/pkg/api/resource"
@@ -111,9 +114,9 @@ func fakeServiceCreate(args []string, withExistingService bool) (
 
 func getServiceEvents(name string) []watch.Event {
 	return []watch.Event{
-		{watch.Added, wait.CreateTestServiceWithConditions(name, corev1.ConditionUnknown, corev1.ConditionUnknown, "", "msg1")},
-		{watch.Modified, wait.CreateTestServiceWithConditions(name, corev1.ConditionUnknown, corev1.ConditionTrue, "", "msg2")},
-		{watch.Modified, wait.CreateTestServiceWithConditions(name, corev1.ConditionTrue, corev1.ConditionTrue, "", "")},
+		{Type: watch.Added, Object: wait.CreateTestServiceWithConditions(name, corev1.ConditionUnknown, corev1.ConditionUnknown, "", "msg1")},
+		{Type: watch.Modified, Object: wait.CreateTestServiceWithConditions(name, corev1.ConditionUnknown, corev1.ConditionTrue, "", "msg2")},
+		{Type: watch.Modified, Object: wait.CreateTestServiceWithConditions(name, corev1.ConditionTrue, corev1.ConditionTrue, "", "")},
 	}
 }
 
@@ -221,7 +224,7 @@ func TestServiceCreateEnv(t *testing.T) {
 	if err != nil {
 		t.Fatal(err)
 	}
-	actualEnvVars, err := servinglib.EnvToMap(template.Spec.Containers[0].Env)
+	actualEnvVars, err := util.EnvToMap(template.Spec.Containers[0].Env)
 	if err != nil {
 		t.Fatal(err)
 	}
@@ -237,34 +240,6 @@ func TestServiceCreateEnv(t *testing.T) {
 	}
 }
 
-func TestServiceCreateWithDeprecatedRequests(t *testing.T) {
-	action, created, _, err := fakeServiceCreate([]string{
-		"service", "create", "foo", "--image", "gcr.io/foo/bar:baz",
-		"--requests-cpu", "250m", "--requests-memory", "64Mi",
-		"--no-wait"}, false)
-
-	if err != nil {
-		t.Fatal(err)
-	} else if !action.Matches("create", "services") {
-		t.Fatalf("Bad action %v", action)
-	}
-
-	expectedRequestsVars := corev1.ResourceList{
-		corev1.ResourceCPU:    parseQuantity(t, "250m"),
-		corev1.ResourceMemory: parseQuantity(t, "64Mi"),
-	}
-
-	template := &created.Spec.Template
-
-	if err != nil {
-		t.Fatal(err)
-	} else if !reflect.DeepEqual(
-		template.Spec.Containers[0].Resources.Requests,
-		expectedRequestsVars) {
-		t.Fatalf("wrong requests vars %v", template.Spec.Containers[0].Resources.Requests)
-	}
-}
-
 func TestServiceCreateWithRequests(t *testing.T) {
 	action, created, _, err := fakeServiceCreate([]string{
 		"service", "create", "foo", "--image", "gcr.io/foo/bar:baz",
@@ -293,34 +268,6 @@ func TestServiceCreateWithRequests(t *testing.T) {
 	}
 }
 
-func TestServiceCreateWithDeprecatedLimits(t *testing.T) {
-	action, created, _, err := fakeServiceCreate([]string{
-		"service", "create", "foo", "--image", "gcr.io/foo/bar:baz",
-		"--limits-cpu", "1000m", "--limits-memory", "1024Mi",
-		"--no-wait"}, false)
-
-	if err != nil {
-		t.Fatal(err)
-	} else if !action.Matches("create", "services") {
-		t.Fatalf("Bad action %v", action)
-	}
-
-	expectedLimitsVars := corev1.ResourceList{
-		corev1.ResourceCPU:    parseQuantity(t, "1000m"),
-		corev1.ResourceMemory: parseQuantity(t, "1024Mi"),
-	}
-
-	template := &created.Spec.Template
-
-	if err != nil {
-		t.Fatal(err)
-	} else if !reflect.DeepEqual(
-		template.Spec.Containers[0].Resources.Limits,
-		expectedLimitsVars) {
-		t.Fatalf("wrong limits vars %v", template.Spec.Containers[0].Resources.Limits)
-	}
-}
-
 func TestServiceCreateWithLimits(t *testing.T) {
 	action, created, _, err := fakeServiceCreate([]string{
 		"service", "create", "foo", "--image", "gcr.io/foo/bar:baz",
@@ -349,45 +296,6 @@ func TestServiceCreateWithLimits(t *testing.T) {
 	}
 }
 
-func TestServiceCreateDeprecatedRequestsLimitsCPU(t *testing.T) {
-	action, created, _, err := fakeServiceCreate([]string{
-		"service", "create", "foo", "--image", "gcr.io/foo/bar:baz",
-		"--requests-cpu", "250m", "--limits-cpu", "1000m",
-		"--no-wait"}, false)
-
-	if err != nil {
-		t.Fatal(err)
-	} else if !action.Matches("create", "services") {
-		t.Fatalf("Bad action %v", action)
-	}
-
-	expectedRequestsVars := corev1.ResourceList{
-		corev1.ResourceCPU: parseQuantity(t, "250m"),
-	}
-
-	expectedLimitsVars := corev1.ResourceList{
-		corev1.ResourceCPU: parseQuantity(t, "1000m"),
-	}
-
-	template := &created.Spec.Template
-
-	if err != nil {
-		t.Fatal(err)
-	} else {
-		if !reflect.DeepEqual(
-			template.Spec.Containers[0].Resources.Requests,
-			expectedRequestsVars) {
-			t.Fatalf("wrong requests vars %v", template.Spec.Containers[0].Resources.Requests)
-		}
-
-		if !reflect.DeepEqual(
-			template.Spec.Containers[0].Resources.Limits,
-			expectedLimitsVars) {
-			t.Fatalf("wrong limits vars %v", template.Spec.Containers[0].Resources.Limits)
-		}
-	}
-}
-
 func TestServiceCreateRequestsLimitsCPU(t *testing.T) {
 	action, created, _, err := fakeServiceCreate([]string{
 		"service", "create", "foo", "--image", "gcr.io/foo/bar:baz",
@@ -427,46 +335,6 @@ func TestServiceCreateRequestsLimitsCPU(t *testing.T) {
 	}
 }
 
-func TestServiceCreateDeprecatedRequestsLimitsMemory(t *testing.T) {
-	action, created, _, err := fakeServiceCreate([]string{
-		"service", "create", "foo",
-		"--image", "gcr.io/foo/bar:baz",
-		"--requests-memory", "64Mi",
-		"--limits-memory", "1024Mi", "--no-wait"}, false)
-
-	if err != nil {
-		t.Fatal(err)
-	} else if !action.Matches("create", "services") {
-		t.Fatalf("Bad action %v", action)
-	}
-
-	expectedRequestsVars := corev1.ResourceList{
-		corev1.ResourceMemory: parseQuantity(t, "64Mi"),
-	}
-
-	expectedLimitsVars := corev1.ResourceList{
-		corev1.ResourceMemory: parseQuantity(t, "1024Mi"),
-	}
-
-	template := &created.Spec.Template
-
-	if err != nil {
-		t.Fatal(err)
-	} else {
-		if !reflect.DeepEqual(
-			template.Spec.Containers[0].Resources.Requests,
-			expectedRequestsVars) {
-			t.Fatalf("wrong requests vars %v", template.Spec.Containers[0].Resources.Requests)
-		}
-
-		if !reflect.DeepEqual(
-			template.Spec.Containers[0].Resources.Limits,
-			expectedLimitsVars) {
-			t.Fatalf("wrong limits vars %v", template.Spec.Containers[0].Resources.Limits)
-		}
-	}
-}
-
 func TestServiceCreateRequestsLimitsMemory(t *testing.T) {
 	action, created, _, err := fakeServiceCreate([]string{
 		"service", "create", "foo",
@@ -510,7 +378,7 @@ func TestServiceCreateRequestsLimitsMemory(t *testing.T) {
 func TestServiceCreateMaxMinScale(t *testing.T) {
 	action, created, _, err := fakeServiceCreate([]string{
 		"service", "create", "foo", "--image", "gcr.io/foo/bar:baz",
-		"--min-scale", "1", "--max-scale", "5",
+		"--scale-min", "1", "--scale-max", "5",
 		"--concurrency-target", "10", "--concurrency-limit", "100",
 		"--concurrency-utilization", "50",
 		"--no-wait"}, false)
@@ -540,15 +408,85 @@ func TestServiceCreateMaxMinScale(t *testing.T) {
 	}
 
 	if *template.Spec.ContainerConcurrency != int64(100) {
-		t.Fatalf("container concurrency not set to given value 1000")
+		t.Fatalf("container concurrency not set to given value 100")
 	}
 }
 
+func TestServiceCreateScale(t *testing.T) {
+	action, created, _, err := fakeServiceCreate([]string{
+		"service", "create", "foo", "--image", "gcr.io/foo/bar:baz",
+		"--scale", "5", "--no-wait"}, false)
+
+	if err != nil {
+		t.Fatal(err)
+	} else if !action.Matches("create", "services") {
+		t.Fatalf("Bad action %v", action)
+	}
+
+	template := &created.Spec.Template
+
+	actualAnnos := template.Annotations
+	expectedAnnos := []string{
+		"autoscaling.knative.dev/minScale", "5",
+		"autoscaling.knative.dev/maxScale", "5",
+	}
+
+	for i := 0; i < len(expectedAnnos); i += 2 {
+		anno := expectedAnnos[i]
+		if actualAnnos[anno] != expectedAnnos[i+1] {
+			t.Fatalf("Unexpected annotation value for %s : %s (actual) != %s (expected)",
+				anno, actualAnnos[anno], expectedAnnos[i+1])
+		}
+	}
+}
+
+func TestServiceCreateScaleWithNegativeValue(t *testing.T) {
+	_, _, _, err := fakeServiceCreate([]string{
+		"service", "create", "foo", "--image", "gcr.io/foo/bar:baz",
+		"--scale", "-1", "--no-wait"}, true)
+	if err == nil {
+		t.Fatal(err)
+	}
+	expectedErrMsg := "expected 0 <= -1 <= 2147483647: autoscaling.knative.dev/maxScale"
+	if !strings.Contains(err.Error(), expectedErrMsg) {
+		t.Errorf("Invalid error output, expected: %s, got : '%s'", expectedErrMsg, err)
+	}
+
+}
+
+func TestServiceCreateScaleWithMaxScaleSet(t *testing.T) {
+	_, _, _, err := fakeServiceCreate([]string{
+		"service", "create", "foo", "--image", "gcr.io/foo/bar:baz",
+		"--scale", "5", "--scale-max", "2", "--no-wait"}, true)
+	if err == nil {
+		t.Fatal(err)
+	}
+	expectedErrMsg := "only --scale or --scale-max can be specified"
+	if !strings.Contains(err.Error(), expectedErrMsg) {
+		t.Errorf("Invalid error output, expected: %s, got : '%s'", expectedErrMsg, err)
+	}
+
+}
+
+func TestServiceCreateScaleWithMinScaleSet(t *testing.T) {
+	_, _, _, err := fakeServiceCreate([]string{
+		"service", "create", "foo", "--image", "gcr.io/foo/bar:baz",
+		"--scale", "5", "--scale-min", "2", "--no-wait"}, true)
+	if err == nil {
+		t.Fatal(err)
+	}
+	expectedErrMsg := "only --scale or --scale-min can be specified"
+	if !strings.Contains(err.Error(), expectedErrMsg) {
+		t.Errorf("Invalid error output, expected: %s, got : '%s'", expectedErrMsg, err)
+	}
+
+}
+
 func TestServiceCreateRequestsLimitsCPUMemory(t *testing.T) {
 	action, created, _, err := fakeServiceCreate([]string{
 		"service", "create", "foo", "--image", "gcr.io/foo/bar:baz",
-		"--requests-cpu", "250m", "--limits-cpu", "1000m",
-		"--requests-memory", "64Mi", "--limits-memory", "1024Mi",
+		"--request", "cpu=250m", "--limit", "cpu=1000m",
+		"--request", "memory=64Mi", "--limit", "memory=1024Mi",
 		"--no-wait"}, false)
 
 	if err != nil {
@@ -652,7 +590,7 @@ func TestServiceCreateEnvForce(t *testing.T) {
 	if err != nil {
 		t.Fatal(err)
 	}
-	actualEnvVars, err := servinglib.EnvToMap(template.Spec.Containers[0].Env)
+	actualEnvVars, err := util.EnvToMap(template.Spec.Containers[0].Env)
 	if err != nil {
 		t.Fatal(err)
 	} else if template.Spec.Containers[0].Image != "gcr.io/foo/bar:v2" {
@@ -700,10 +638,253 @@ func TestServiceCreateWithClusterLocal(t *testing.T) {
 
 	labels := created.ObjectMeta.Labels
 
-	labelValue, present := labels[serving.VisibilityLabelKey]
+	labelValue, present := labels[network.VisibilityLabelKey]
 	assert.Assert(t, present)
 
 	if labelValue != serving.VisibilityClusterLocal {
 		t.Fatalf("Incorrect VisibilityClusterLocal value '%s'", labelValue)
 	}
 }
+
+var serviceYAML = `
+apiVersion: serving.knative.dev/v1
+kind: Service
+metadata:
+  name: foo
+spec:
+  template:
+    spec:
+      containers:
+        - image: gcr.io/foo/bar:baz
+          env:
+            - name: TARGET
+              value: "Go Sample v1"
+`
+
+var serviceJSON = `
+{
+  "apiVersion": "serving.knative.dev/v1",
+  "kind": "Service",
+  "metadata": {
+    "name": "foo"
+  },
+  "spec": {
+    "template": {
+		"spec": {
+		"containers": [
+			{
+			"image": "gcr.io/foo/bar:baz",
+			"env": [
+				{
+				"name": "TARGET",
+				"value": "Go Sample v1"
+				}
+			]
+		  }
+		]
+	  }
+	}
+  }
+}`
+
+func TestServiceCreateFromFile(t *testing.T) {
+	testWithServiceFiles(t, func(t *testing.T, tempFile string) {
+		for _, testArgs := range [][]string{
+			{
+				"service", "create", "foo", "--filename", tempFile}, {
+				"service", "create", "--filename", tempFile},
+		} {
+			action, created, _, err := fakeServiceCreate(testArgs, false)
+			assert.NilError(t, err)
+			assert.Assert(t, action.Matches("create", "services"))
+
+			assert.Equal(t, created.Name, "foo")
+			assert.Equal(t, created.Spec.Template.Spec.GetContainer().Image, "gcr.io/foo/bar:baz")
+		}
+	})
+}
+
+func testWithServiceFiles(t *testing.T, testFunction func(t *testing.T, file string)) {
+	tempDir, err := ioutil.TempDir("", "kn-file")
+	defer os.RemoveAll(tempDir)
+	assert.NilError(t, err)
+
+	for _, d := range []struct {
+		filename string
+		content  string
+	}{
+		{"service.yaml",
+			serviceYAML,
+		},
+		{"service.json",
+			serviceJSON,
+		},
+	} {
+		tempFile := filepath.Join(tempDir, d.filename)
+		err = ioutil.WriteFile(tempFile, []byte(d.content), os.FileMode(0666))
+		assert.NilError(t, err)
+		testFunction(t, tempFile)
+	}
+}
+
+func TestServiceCreateFileNameMismatch(t *testing.T) {
+	testWithServiceFiles(t, func(t *testing.T, tempFile string) {
+		_, _, _, err := fakeServiceCreate([]string{
+			"service", "create", "anotherFoo", "--filename", tempFile}, false)
+		assert.Assert(t, err != nil)
+		assert.Assert(t, util.ContainsAllIgnoreCase(err.Error(), "provided", "'anotherFoo'", "name", "match", "from", "file", "'foo'"))
+
+		err = ioutil.WriteFile(tempFile, []byte(strings.ReplaceAll(serviceYAML, "name: foo", "")), os.FileMode(0666))
+		assert.NilError(t, err)
+		_, _, _, err = fakeServiceCreate([]string{
+			"service", "create", "--filename", tempFile}, false)
+		assert.Assert(t, err != nil)
+		assert.Assert(t, util.ContainsAllIgnoreCase(err.Error(), "no", "service", "name", "provided", "parameter", "file"))
+
+	})
+}
+
+func TestServiceCreateFileError(t *testing.T) {
+	_, _, _, err := fakeServiceCreate([]string{
+		"service", "create", "foo", "--filename", "filepath"}, false)
+
+	assert.Assert(t, util.ContainsAll(err.Error(), "no", "such", "file", "directory", "filepath"))
+}
+
+func TestServiceCreateInvalidDataJSON(t *testing.T) {
+	tempDir, err := ioutil.TempDir("", "kn-file")
+	defer os.RemoveAll(tempDir)
+	assert.NilError(t, err)
+	tempFile := filepath.Join(tempDir, "invalid.json")
+
+	// Double curly bracket at the beginning of file
+	invalidData := strings.Replace(serviceJSON, "{\n", "{{\n", 1)
+	err = ioutil.WriteFile(tempFile, []byte(invalidData), os.FileMode(0666))
+	assert.NilError(t, err)
+	_, _, _, err = fakeServiceCreate([]string{"service", "create", "foo", "--filename", tempFile}, false)
+	assert.Assert(t, util.ContainsAll(err.Error(), "invalid", "character", "'{'", "beginning"))
+
+	// Remove closing quote on key
+	invalidData = strings.Replace(serviceJSON, "metadata\"", "metadata", 1)
+	err = ioutil.WriteFile(tempFile, []byte(invalidData), os.FileMode(0666))
+	assert.NilError(t, err)
+	_, _, _, err = fakeServiceCreate([]string{"service", "create", "foo", "--filename", tempFile}, false)
+	assert.Assert(t, util.ContainsAll(err.Error(), "invalid", "character", "'\\n'", "string", "literal"))
+
+	// Remove opening square bracket
+	invalidData = strings.Replace(serviceJSON, " [", "", 1)
+	err = ioutil.WriteFile(tempFile, []byte(invalidData), os.FileMode(0666))
+	assert.NilError(t, err)
+	_, _, _, err = fakeServiceCreate([]string{"service", "create", "foo", "--filename", tempFile}, false)
+	assert.Assert(t, util.ContainsAll(err.Error(), "invalid", "character", "']'", "after", "key:value"))
+}
+
+func TestServiceCreateInvalidDataYAML(t *testing.T) {
+	tempDir, err := ioutil.TempDir("", "kn-file")
+	defer os.RemoveAll(tempDir)
+	assert.NilError(t, err)
+	tempFile := filepath.Join(tempDir, "invalid.yaml")
+
+	// Remove dash
+	invalidData := strings.Replace(serviceYAML, "- image", "image", 1)
+	err = ioutil.WriteFile(tempFile, []byte(invalidData), os.FileMode(0666))
+	assert.NilError(t, err)
+	_, _, _, err = fakeServiceCreate([]string{"service", "create", "foo", "--filename", tempFile}, false)
+	assert.Assert(t, util.ContainsAll(err.Error(), "mapping", "values", "not", "allowed"))
+
+	// Remove name key
+	invalidData = strings.Replace(serviceYAML, "name:", "", 1)
+	err = ioutil.WriteFile(tempFile, []byte(invalidData), os.FileMode(0666))
+	assert.NilError(t, err)
+	_, _, _, err = fakeServiceCreate([]string{"service", "create", "foo", "--filename", tempFile}, false)
+	assert.Assert(t, util.ContainsAll(err.Error(), "cannot", "unmarshal", "Go", "struct", "Service.metadata"))
+
+	// Remove opening square bracket
+	invalidData = strings.Replace(serviceYAML, "env", "\tenv", 1)
+	err = ioutil.WriteFile(tempFile, []byte(invalidData), os.FileMode(0666))
+	assert.NilError(t, err)
+	_, _, _, err = fakeServiceCreate([]string{"service", "create", "foo", "--filename", tempFile}, false)
+	assert.Assert(t, util.ContainsAll(err.Error(), "found", "tab", "violates", "indentation"))
+}
+
+func TestServiceCreateFromYAMLWithOverride(t *testing.T) {
+	tempDir, err := ioutil.TempDir("", "kn-file")
+	defer os.RemoveAll(tempDir)
+	assert.NilError(t, err)
+
+	tempFile := filepath.Join(tempDir, "service.yaml")
+	err = ioutil.WriteFile(tempFile, []byte(serviceYAML), os.FileMode(0666))
+	assert.NilError(t, err)
+	// Merge env vars
+	expectedEnvVars := map[string]string{
+		"TARGET": "Go Sample v1",
+		"FOO":    "BAR"}
+	action, created, _, err := fakeServiceCreate([]string{
+		"service", "create", "foo", "--filename", tempFile, "--env", "FOO=BAR"}, false)
+	assert.NilError(t, err)
+	assert.Assert(t, action.Matches("create", "services"))
+	assert.Equal(t, created.Name, "foo")
+
+	actualEnvVar, err := util.EnvToMap(created.Spec.Template.Spec.GetContainer().Env)
+	assert.NilError(t, err)
+	assert.DeepEqual(t, actualEnvVar, expectedEnvVars)
+
+	// Override env vars
+	expectedEnvVars = map[string]string{
+		"TARGET": "FOOBAR",
+		"FOO":    "BAR"}
+	action, created, _, err = fakeServiceCreate([]string{
+		"service", "create", "foo", "--filename", tempFile, "--env", "TARGET=FOOBAR", "--env", "FOO=BAR"}, false)
+	assert.NilError(t, err)
+	assert.Assert(t, action.Matches("create", "services"))
+	assert.Equal(t, created.Name, "foo")
+
+	actualEnvVar, err = util.EnvToMap(created.Spec.Template.Spec.GetContainer().Env)
+	assert.NilError(t, err)
+	assert.DeepEqual(t, actualEnvVar, expectedEnvVars)
+
+	// Remove existing env vars
+	expectedEnvVars = map[string]string{
+		"FOO": "BAR"}
+	action, created, _, err = fakeServiceCreate([]string{
+		"service", "create", "foo", "--filename", tempFile, "--env", "TARGET-", "--env", "FOO=BAR"}, false)
+	assert.NilError(t, err)
+	assert.Assert(t, action.Matches("create", "services"))
+	assert.Equal(t, created.Name, "foo")
+
+	actualEnvVar, err = util.EnvToMap(created.Spec.Template.Spec.GetContainer().Env)
+	assert.NilError(t, err)
+	assert.DeepEqual(t, actualEnvVar, expectedEnvVars)
+
+	// Multiple edit flags
+	expectedAnnotations := map[string]string{
+		"foo": "bar"}
+	action, created, _, err = fakeServiceCreate([]string{"service", "create", "foo", "--filename", tempFile,
+		"--service-account", "foo", "--cmd", "/foo/bar", "-a", "foo=bar"}, false)
+	assert.NilError(t, err)
+	assert.Assert(t, action.Matches("create", "services"))
+	assert.Equal(t, created.Name, "foo")
+	assert.DeepEqual(t, created.Spec.Template.Spec.GetContainer().Command, []string{"/foo/bar"})
+	assert.Equal(t, created.Spec.Template.Spec.ServiceAccountName, "foo")
+	assert.DeepEqual(t, created.ObjectMeta.Annotations, expectedAnnotations)
+}
+
+func TestServiceCreateFromYAMLWithOverrideError(t *testing.T) {
+	tempDir, err := ioutil.TempDir("", "kn-file")
+	defer os.RemoveAll(tempDir)
+	assert.NilError(t, err)
+
+	tempFile := filepath.Join(tempDir, "service.yaml")
+	err = ioutil.WriteFile(tempFile, []byte(serviceYAML), os.FileMode(0666))
+	assert.NilError(t, err)
+
+	_, _, _, err = fakeServiceCreate([]string{
+		"service", "create", "foo", "--filename", tempFile, "--image", "foo/bar", "--image", "bar/foo"}, false)
+	assert.Assert(t, err != nil)
+	assert.Assert(t, util.ContainsAll(err.Error(), "\"--image\"", "invalid", "argument", "only", "once"))
+
+	_, _, _, err = fakeServiceCreate([]string{
+		"service", "create", "foo", "--filename", tempFile, "--scale", "-1"}, false)
+	assert.Assert(t, err != nil)
+	assert.Assert(t, util.ContainsAll(err.Error(), "expected", "0", "<=", "2147483647", "autoscaling.knative.dev/maxScale"))
+}
